@@ -54,7 +54,7 @@
 #include "FileEntry.h"
 #include "A2STR.h"
 #include "a2functional.h"
-#include "DownloadHandlerConstants.h"
+#include "download_helper.h"
 #ifdef ENABLE_BITTORRENT
 # include "BtDependency.h"
 # include "download_helper.h"
@@ -110,7 +110,16 @@ Metalink2RequestGroup::generate
 {
   std::vector<SharedHandle<MetalinkEntry> > entries;
   MetalinkHelper::parseAndQuery(entries, metalinkFile, option.get());
-  createRequestGroup(groups, entries, option);
+  std::vector<SharedHandle<RequestGroup> > tempgroups;
+  createRequestGroup(tempgroups, entries, option);
+  SharedHandle<MetadataInfo> mi;
+  if(metalinkFile == "-") {
+    mi.reset(new MetadataInfo());
+  } else {
+    mi.reset(new MetadataInfo(metalinkFile));
+  }
+  setMetadataInfo(tempgroups.begin(), tempgroups.end(), mi);
+  groups.insert(groups.end(), tempgroups.begin(), tempgroups.end());
 }
 
 void
@@ -121,19 +130,11 @@ Metalink2RequestGroup::generate
 {
   std::vector<SharedHandle<MetalinkEntry> > entries;
   MetalinkHelper::parseAndQuery(entries, binaryStream, option.get());
-  createRequestGroup(groups, entries, option);
-}
-
-namespace {
-void removeMetalinkContentTypes(const SharedHandle<RequestGroup>& group)
-{
-  for(std::vector<std::string>::const_iterator i =
-	DownloadHandlerConstants::getMetalinkContentTypes().begin(),
-        eoi = DownloadHandlerConstants::getMetalinkContentTypes().end();
-      i != eoi; ++i) {
-    group->removeAcceptType(*i);
-  }
-}
+  std::vector<SharedHandle<RequestGroup> > tempgroups;
+  createRequestGroup(tempgroups, entries, option);
+  SharedHandle<MetadataInfo> mi(new MetadataInfo());
+  setMetadataInfo(tempgroups.begin(), tempgroups.end(), mi);
+  groups.insert(groups.end(), tempgroups.begin(), tempgroups.end());
 }
 
 void
@@ -213,7 +214,7 @@ Metalink2RequestGroup::createRequestGroup
         torrentRg->clearPostDownloadHandler();
         // remove "metalink" from Accept Type list to avoid loop in
         // tranparent metalink
-        removeMetalinkContentTypes(torrentRg);
+        util::removeMetalinkContentTypes(torrentRg);
         // make it in-memory download
         SharedHandle<PreDownloadHandler> preh
           (new MemoryBufferPreDownloadHandler());
@@ -306,7 +307,7 @@ Metalink2RequestGroup::createRequestGroup
     rg->setDownloadContext(dctx);
     // remove "metalink" from Accept Type list to avoid loop in
     // tranparent metalink
-    removeMetalinkContentTypes(rg);
+    util::removeMetalinkContentTypes(rg);
 #ifdef ENABLE_BITTORRENT
     // Inject depenency between rg and torrentRg here if
     // torrentRg.isNull() == false
